@@ -183,7 +183,7 @@ class WeaviateHook(BaseHook):
         client.schema.create(schema_json)
 
     @staticmethod
-    def _convert_dataframe_to_list(data: list[dict[str, Any]] | pd.DataFrame) -> list[dict[str, Any]]:
+    def _convert_dataframe_to_list(data: list[dict[str, Any]] | pd.DataFrame | None) -> list[dict[str, Any]]:
         """Helper function to convert dataframe to list of dicts.
 
         In scenario where Pandas isn't installed and we pass data as a list of dictionaries, importing
@@ -280,9 +280,7 @@ class WeaviateHook(BaseHook):
         intersection_classes = set__exiting_classes.intersection(set__to_be_added_classes)
         classes_to_create = set()
         if existing == "fail" and intersection_classes:
-            raise ValueError(
-                f"Trying to create class {intersection_classes}" f" but this class already exists."
-            )
+            raise ValueError(f"Trying to create class {intersection_classes} but this class already exists.")
         elif existing == "ignore":
             classes_to_create = set__to_be_added_classes - set__exiting_classes
         elif existing == "replace":
@@ -384,7 +382,7 @@ class WeaviateHook(BaseHook):
     def batch_data(
         self,
         class_name: str,
-        data: list[dict[str, Any]] | pd.DataFrame,
+        data: list[dict[str, Any]] | pd.DataFrame | None,
         batch_config_params: dict[str, Any] | None = None,
         vector_col: str = "Vector",
         uuid_col: str = "id",
@@ -403,7 +401,7 @@ class WeaviateHook(BaseHook):
         :param retry_attempts_per_object: number of time to try in case of failure before giving up.
         :param tenant: The tenant to which the object will be added.
         """
-        data = self._convert_dataframe_to_list(data)
+        converted_data = self._convert_dataframe_to_list(data)
         total_results = 0
         error_results = 0
         insertion_errors: list = []
@@ -439,7 +437,7 @@ class WeaviateHook(BaseHook):
 
                 self.log.info(
                     "Total Objects %s / Objects %s successfully inserted and Objects %s had errors.",
-                    len(data),
+                    len(converted_data),
                     total_results,
                     error_results,
                 )
@@ -462,7 +460,7 @@ class WeaviateHook(BaseHook):
         client.batch.configure(**batch_config_params)
         with client.batch as batch:
             # Batch import all data
-            for index, data_obj in enumerate(data):
+            for index, data_obj in enumerate(converted_data):
                 for attempt in Retrying(
                     stop=stop_after_attempt(retry_attempts_per_object),
                     retry=(
